(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     55530,       2537]*)
(*NotebookOutlinePosition[     66571,       2860]*)
(*  CellTagsIndexPosition[     65731,       2823]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "NumericalMath",
  StyleBox["`", "MB"],
  "Microscope",
  StyleBox["`", "MB"]
}], "Subsection",
  CellTags->{"S5.86.1", "1.1"}],

Cell[TextData[{
  StyleBox["Mathematica", "TI"],
  " uses both the machine arithmetic that is provided by the machine and its \
own arbitrary\[Hyphen]precision arithmetic, which is the same on all machines \
(except for the variations in the size of the largest representable number \
and the amount of memory on the machine). This package deals with the \
floating\[Hyphen]point arithmetic provided by the machine, not the arbitrary\
\[Hyphen]precision arithmetic of ",
  StyleBox["Mathematica", "TI"],
  ". \nNumbers on a computer comprise a discrete set. There are gaps between \
the numbers and when you do arithmetic the result often is not representable. \
When the result falls between two representable numbers the best that can be \
done is to use the closest representable number as the result instead of the \
correct result. We commonly refer to the set of numbers that can be \
represented on a computer in floating\[Hyphen]point format as the set of \
machine numbers. If you want to investigate how arithmetic is done on \
computers in a general sense you should use the package ",
  StyleBox["NumericalMath`ComputerArithmetic`", "MR"],
  ". That package allows you to vary certain fundamental parameters that \
control the arithmetic. \nThe difference between two consecutive machine \
numbers is called an ulp (",
  StyleBox["u", "TI"],
  "nit in the ",
  StyleBox["l", "TI"],
  "ast ",
  StyleBox["p", "TI"],
  "lace, ",
  StyleBox["i.e.", "TI"],
  ", one digit in the least significant place). The size of an ulp varies \
depending on where you are in the set of machine numbers. Between ",
  Cell[BoxData[
      \(TraditionalForm\`1\)], "InlineFormula",
    CellTags->"S5.86.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`2\)], "InlineFormula",
    CellTags->"S5.86.1"],
  " an ulp is equal to ",
  StyleBox["$MachineEpsilon", "MR"],
  ". Between ",
  Cell[BoxData[
      \(TraditionalForm\`2\)], "InlineFormula",
    CellTags->"S5.86.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`4\)], "InlineFormula",
    CellTags->"S5.86.1"],
  " it is equal to ",
  StyleBox["2", "MR"],
  " ",
  StyleBox["$MachineEpsilon", "MR"],
  ". Ideally no function should ever return a result with error exceeding \
half of an ulp since the distance from the true result to the nearest machine \
number is always less than half of an ulp, the worst case being when it is \
exactly halfway between two machine numbers. It is relatively easy to achieve \
this ideal for the four arithmetic operations and for the square root \
function. For the elementary transcendental functions it becomes more \
difficult due to the fact that they cannot be evaluated in a single operation \
and the combined effects of all the rounding errors would have to be made \
less than half an ulp. Nevertheless, it is quite possible to design \
algorithms for these functions such that the error is never more than one \
ulp. \nThe package ",
  StyleBox["NumericalMath`Microscope`", "MR"],
  " provides four functions that are useful in examining the machine floating\
\[Hyphen]point arithmetic on your machine. "
}], "Text",
  CellTags->{"S5.86.1", "1.2"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Ulp[\\\\\\\"\\\", \\\"MR\
\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"a\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", "\<\"give the size of an ulp near \
\\!\\(\\*StyleBox[\\\"\\\\\\\"a\\\\\\\"\\\", \\\"TI\\\"]\\)\"\>"},
                {
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"MachineError[\\\\\\\"\\\"\
, \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"f\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"x\\\\\\\"\\\", \\\"TI\\\"]\\) \\!\\(\\*StyleBox[\\\
\"\\\\\\\"->\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"a\\\\\\\"\\\", \\\"TI\\\"]\\)\\!\\(\\*StyleBox[\
\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \"\>", 
                  "\<\"give the error in evaluating \
\\!\\(\\*StyleBox[\\\"\\\\\\\"f\\\\\\\"\\\", \\\"TI\\\"]\\) at \
\\!\\(\\*StyleBox[\\\"\\\\\\\"x\\\\\\\"\\\", \\\"TI\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"=\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"a\\\\\\\"\\\", \\\"TI\\\"]\\) using machine \
arithmetic\"\>"},
                {
                  RowBox[{
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Microscope[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"f\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                    StyleBox["{",
                      "InlineFormula"], 
                    "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"x\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"a\\\\\\\"\\\", \\\"TI\\\"]\\)\"\>", 
                    StyleBox["}",
                      "InlineFormula"], 
                    "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>"}], 
                  "\<\"plot \\!\\(\\*StyleBox[\\\"\\\\\\\"f\\\\\\\"\\\", \
\\\"TI\\\"]\\) near \\!\\(\\*StyleBox[\\\"\\\\\\\"x\\\\\\\"\\\", \
\\\"TI\\\"]\\) \\!\\(\\*StyleBox[\\\"\\\\\\\"=\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"a\\\\\\\"\\\", \\\"TI\\\"]\\) using machine \
arithmetic\"\>"},
                {
                  RowBox[{
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"MicroscopicError[\\\\\\\"\
\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"f\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                    StyleBox["{",
                      "InlineFormula"], 
                    "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"x\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"a\\\\\\\"\\\", \\\"TI\\\"]\\)\"\>", 
                    StyleBox["}",
                      "InlineFormula"], 
                    "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>"}], 
                  "\<\"plot the error in evaluating \
\\!\\(\\*StyleBox[\\\"\\\\\\\"f\\\\\\\"\\\", \\\"TI\\\"]\\) near \
\\!\\(\\*StyleBox[\\\"\\\\\\\"x\\\\\\\"\\\", \\\"TI\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"=\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"a\\\\\\\"\\\", \\\"TI\\\"]\\) using machine \
arithmetic\"\>"}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S5.86.1", "1.3"}],

Cell["Functions for examining machine floating\[Hyphen]point arithmetic. ", 
  "Caption",
  CellTags->"S5.86.1"],

Cell[TextData[{
  "The default neighborhood of the point ",
  StyleBox["x", "TI"],
  " ",
  StyleBox["=", "MR"],
  " ",
  StyleBox["a", "TI"],
  " used in ",
  StyleBox["Microscope", "MR"],
  " and ",
  StyleBox["MicroscopicError", "MR"],
  " is from 30 ulps to the left of ",
  StyleBox["a", "TI"],
  " to 30 ulps to the right of ",
  StyleBox["a", "TI"],
  ", where the ulp used is that defined at ",
  StyleBox["x", "TI"],
  " ",
  StyleBox["=", "MR"],
  " ",
  StyleBox["a", "TI"],
  ", that is, ",
  StyleBox["Ulp[", "MR"],
  StyleBox["a", "TI"],
  StyleBox["]", "MR"],
  ". Near powers of 2 and near 0 it is not clear what should be done since \
the size of an ulp changes. Near powers of 2 it is not much of a problem in \
the abscissa since an ulp is chosen to be the smaller of the two values and \
the resulting machine numbers just get included multiple times due to \
rounding effects. You can change the default size of the neighborhood by \
including a third value in the neighborhood specification. \nA problem arises \
with ",
  StyleBox["Microscope", "MR"],
  " and ",
  StyleBox["MicroscopicError", "MR"],
  " near places where the function value becomes infinite. Since the function \
is changing by orders of magnitude very rapidly it is difficult to choose a \
good scale that displays the information in which you are interested. In such \
cases you may have to examine the function several hundreds of ulps away from \
the point you really want. "
}], "Text",
  CellTags->{"S5.86.1", "1.4"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Microscope[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"f\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                    StyleBox["{",
                      "InlineFormula"], 
                    "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"x\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"a\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \\\"TI\\\"]\\)\"\>", 
                    StyleBox["}",
                      "InlineFormula"], 
                    "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>"}], 
                  "\<\"plot \\!\\(\\*StyleBox[\\\"\\\\\\\"f\\\\\\\"\\\", \
\\\"TI\\\"]\\) from \\!\\(\\*StyleBox[\\\"\\\\\\\"x\\\\\\\"\\\", \
\\\"TI\\\"]\\) \\!\\(\\*StyleBox[\\\"\\\\\\\"=\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"a\\\\\\\"\\\", \\\"TI\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"-\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \\\"TI\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"Ulp[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"a\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) to \
\\!\\(\\*StyleBox[\\\"\\\\\\\"x\\\\\\\"\\\", \\\"TI\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"=\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"a\\\\\\\"\\\", \\\"TI\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"+\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \\\"TI\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"Ulp[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"a\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
using machine arithmetic\"\>"},
                {
                  RowBox[{
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"MicroscopicError[\\\\\\\"\
\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"f\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                    StyleBox["{",
                      "InlineFormula"], 
                    "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"x\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"a\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \\\"TI\\\"]\\)\"\>", 
                    StyleBox["}",
                      "InlineFormula"], 
                    "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>"}], 
                  "\<\"plot the error in evaluating \
\\!\\(\\*StyleBox[\\\"\\\\\\\"f\\\\\\\"\\\", \\\"TI\\\"]\\) from \
\\!\\(\\*StyleBox[\\\"\\\\\\\"x\\\\\\\"\\\", \\\"TI\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"=\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"a\\\\\\\"\\\", \\\"TI\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"-\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \\\"TI\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"Ulp[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"a\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) to \
\\!\\(\\*StyleBox[\\\"\\\\\\\"x\\\\\\\"\\\", \\\"TI\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"=\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"a\\\\\\\"\\\", \\\"TI\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"+\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \\\"TI\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"Ulp[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"a\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
using machine arithmetic\"\>"}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S5.86.1", "1.5"}],

Cell["Controlling the size of the neighborhood. ", "Caption",
  CellTags->"S5.86.1"],

Cell[TextData[{
  "The option ",
  StyleBox["PlotJoined", "MR"],
  " controls the way the plot is drawn. It cannot be overemphasized that the \
functions that we are examining map the machine numbers to the machine \
numbers. For our purposes the real numbers in between do not even exist. Thus \
the plots produced by ",
  StyleBox["Microscope", "MR"],
  " and ",
  StyleBox["MicroscopicError", "MR"],
  " should be nothing but a set of plotted points. However, it is easier to \
see what is happening if the points are joined with straight line segments. \
Finally, if you want to see what a function does as a map from the real \
numbers to the real numbers, that is, rounding the real argument to the \
nearest machine number and applying the function to this result, you can do \
so, but when you see large errors, don't conclude that the function is to \
blame; it can't do any better than deal with the machine numbers that it gets \
as arguments. "
}], "Text",
  CellTags->{"S5.86.1", "1.6"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"option name\\\\\\\"\\\", \
\\\"TI\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"default \
value\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>", "\[Null]"},
                {
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"PlotJoined\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"True\\\\\\\"\\\", \\\"MR\
\\\"]\\) \"\>", 
                  "\<\"the way the points are to be connected; either \
\\!\\(\\*StyleBox[\\\"\\\\\\\"True\\\\\\\"\\\", \\\"MR\\\"]\\), \
\\!\\(\\*StyleBox[\\\"\\\\\\\"False\\\\\\\"\\\", \\\"MR\\\"]\\), or \
\\!\\(\\*StyleBox[\\\"\\\\\\\"Real\\\\\\\"\\\", \\\"MR\\\"]\\)\"\>"}
                },
              ColumnAlignments->{Left}],
            GridBoxOptions->{RowLines->True}]],
        "3ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S5.86.1", "1.7"}],

Cell[TextData[{
  "Options for ",
  StyleBox["Microscope", "MR"],
  " and ",
  StyleBox["MicroscopicError", "MR"],
  "."
}], "Caption",
  CellTags->"S5.86.1"],

Cell["This loads the package. ", "MathCaption",
  CellTags->{"S5.86.1", "1.8"}],

Cell["<<NumericalMath`Microscope`", "Input",
  CellLabel->"In[1]:= ",
  CellTags->"S5.86.1"],

Cell["Here is the size of an ulp at 1. ", "MathCaption",
  CellTags->{"S5.86.1", "1.9"}],

Cell["Ulp[1]", "Input",
  CellLabel->"In[2]:= ",
  CellTags->"S5.86.1"],

Cell[BoxData[
    \(1.11022302462515654`*^-16\)], "Output",
  CellLabel->"Out[2]= ",
  CellTags->"S5.86.1"],

Cell["The size of an ulp changes at powers of 2. ", "MathCaption",
  CellTags->{"S5.86.1", "1.10"}],

Cell["{Ulp[7.999999], Ulp[8], Ulp[8.000001]}", "Input",
  CellLabel->"In[3]:= ",
  CellTags->"S5.86.1"],

Cell[BoxData[
    \({8.88178419700125232`*^-16, 8.88178419700125232`*^-16, 
      1.77635683940025046`*^-15}\)], "Output",
  CellLabel->"Out[3]= ",
  CellTags->"S5.86.1"],

Cell["There is a large hole near 0. ", "MathCaption",
  CellTags->{"S5.86.1", "1.11"}],

Cell["{Ulp[0], Ulp[$MinMachineNumber]}", "Input",
  CellLabel->"In[4]:= ",
  CellTags->"S5.86.1"],

Cell[BoxData[
    \({2.2250738585072014`*^-308, 4.94065645841246544176568793`15.9546*^-324}
      \)], "Output",
  CellLabel->"Out[4]= ",
  CellTags->"S5.86.1"],

Cell[TextData[{
  "Here are the combined errors of rounding ",
  Cell[BoxData[
      \(TraditionalForm\`49  \[Pi]/50\)], "InlineFormula",
    CellTags->"S5.86.1"],
  " to the nearest machine number and then taking the square root. "
}], "MathCaption",
  CellTags->{"S5.86.1", "1.12"}],

Cell["MachineError[Sqrt[x], x -> 49 Pi/50]", "Input",
  CellLabel->"In[5]:= ",
  CellTags->"S5.86.1"],

Cell[BoxData[
    \(\(-1.22218789820841622`\)\ Ulps\)], "Output",
  CellLabel->"Out[5]= ",
  CellTags->"S5.86.1"],

Cell["Here is the error of just the square root. ", "MathCaption",
  CellTags->{"S5.86.1", "1.13"}],

Cell["MachineError[Sqrt[x], x -> N[49 Pi/50]]", "Input",
  CellLabel->"In[6]:= ",
  CellTags->"S5.86.1"],

Cell[BoxData[
    \(\(-0.954183817470033446`\)\ Ulps\)], "Output",
  CellLabel->"Out[6]= ",
  CellTags->"S5.86.1"],

Cell["\<\
In fact the square root function is quite bad on this computer. \
\
\>", "MathCaption",
  CellTags->{"S5.86.1", "1.14"}],

Cell["\<\
MachineError[Sqrt[x],
  x -> N[49 Pi/50] - 6 Ulp[49 Pi/50]]\
\>", "Input",
  CellLabel->"In[7]:= ",
  CellTags->"S5.86.1"],

Cell[BoxData[
    \(\(-0.534678556886323974`\)\ Ulps\)], "Output",
  CellLabel->"Out[7]= ",
  CellTags->"S5.86.1"],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      \(TraditionalForm\`tan \((\@e\^\(sin \((log  x)\)\))\)\)], 
    "InlineFormula",
    CellTags->"S5.86.1"],
  " is not provided by the computer manufacturer so it is evaluated as a \
nested sequence of operations that are provided. This shows how much error is \
involved in the sequence, but this information is rarely useful. For testing \
purposes one normally wants to look at an individual function evaluated at a \
machine number to avoid the effect of an ill\[Hyphen]conditioned function \
magnifying prior error. "
}], "MathCaption",
  CellTags->{"S5.86.1", "1.15"}],

Cell["\<\
MachineError[Tan[Sqrt[Exp[Sin[Log[x]]]]],
 x -> N[Pi]]\
\>", "Input",
  CellLabel->"In[8]:= ",
  CellTags->"S5.86.1"],

Cell[BoxData[
    \(201.108870355740343`\ Ulps\)], "Output",
  CellLabel->"Out[8]= ",
  CellTags->"S5.86.1"],

Cell[TextData[{
  "Here is the ",
  Cell[BoxData[
      \(TraditionalForm\`log\)], "InlineFormula",
    CellTags->"S5.86.1"],
  " function evaluated at machine numbers near 7. "
}], "MathCaption",
  CellTags->{"S5.86.1", "1.16"}],

Cell["\<\
Microscope[Log[x], {x, 7},
 PlotJoined -> False]\
\>", "Input",
  CellLabel->"In[9]:= ",
  CellTags->"S5.86.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.015873 0.309017 0.27699 [
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.01131 .30902 -42 -4.5 ]
[.01131 .30902 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.5 .01472 m
.5 .02097 L
s
[(7.)] .5 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
.02381 .30902 m
.03006 .30902 L
s
[(1.94591)] .01131 .30902 1 0 Mshowa
.02381 0 m
.02381 .61803 L
s
.00667 w
.02381 .01472 Mdot
.03968 .03203 Mdot
.05556 .03203 Mdot
.07143 .04934 Mdot
.0873 .04934 Mdot
.10317 .06665 Mdot
.11905 .08396 Mdot
.13492 .08396 Mdot
.15079 .10127 Mdot
.16667 .10127 Mdot
.18254 .11859 Mdot
.19841 .11859 Mdot
.21429 .1359 Mdot
.23016 .15321 Mdot
.24603 .15321 Mdot
.2619 .17052 Mdot
.27778 .17052 Mdot
.29365 .18783 Mdot
.30952 .18783 Mdot
.3254 .20515 Mdot
.34127 .22246 Mdot
.35714 .22246 Mdot
.37302 .23977 Mdot
.38889 .23977 Mdot
.40476 .25708 Mdot
.42063 .25708 Mdot
.43651 .27439 Mdot
.45238 .29171 Mdot
.46825 .29171 Mdot
.48413 .30902 Mdot
.5 .30902 Mdot
.51587 .32633 Mdot
.53175 .32633 Mdot
.54762 .34364 Mdot
.56349 .36095 Mdot
.57937 .36095 Mdot
.59524 .37826 Mdot
.61111 .37826 Mdot
.62698 .39558 Mdot
.64286 .39558 Mdot
.65873 .41289 Mdot
.6746 .4302 Mdot
.69048 .4302 Mdot
.70635 .44751 Mdot
.72222 .44751 Mdot
.7381 .46482 Mdot
.75397 .46482 Mdot
.76984 .48214 Mdot
.78571 .49945 Mdot
.80159 .49945 Mdot
.81746 .51676 Mdot
.83333 .51676 Mdot
.84921 .53407 Mdot
.86508 .53407 Mdot
.88095 .55138 Mdot
.89683 .5687 Mdot
.9127 .5687 Mdot
.92857 .58601 Mdot
.94444 .58601 Mdot
.96032 .60332 Mdot
.97619 .60332 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S5.86.1"],

Cell[TextData[{
  "Here is the ",
  Cell[BoxData[
      \(TraditionalForm\`log\)], "InlineFormula",
    CellTags->"S5.86.1"],
  " function evaluated at ",
  Cell[BoxData[
      \(TraditionalForm\`10 + 1 + 10\)], "InlineFormula",
    CellTags->"S5.86.1"],
  " machine numbers near 7 with the points joined by straight lines. "
}], "MathCaption",
  CellTags->{"S5.86.1", "1.17"}],

Cell["Microscope[Log[x], {x, 7, 10}]", "Input",
  CellLabel->"In[10]:= ",
  CellTags->"S5.86.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.282262 0.428075 [
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.01131 .28226 -42 -4.5 ]
[.01131 .28226 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.5 .01472 m
.5 .02097 L
s
[(7.)] .5 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
.02381 .28226 m
.03006 .28226 L
s
[(1.94591)] .01131 .28226 1 0 Mshowa
.02381 0 m
.02381 .61803 L
s
.02 w
.02381 .01472 Mdot
.07143 .01472 Mdot
.11905 .06822 Mdot
.16667 .06822 Mdot
.21429 .12173 Mdot
.2619 .12173 Mdot
.30952 .17524 Mdot
.35714 .22875 Mdot
.40476 .22875 Mdot
.45238 .28226 Mdot
.5 .28226 Mdot
.54762 .33577 Mdot
.59524 .33577 Mdot
.64286 .38928 Mdot
.69048 .44279 Mdot
.7381 .44279 Mdot
.78571 .4963 Mdot
.83333 .4963 Mdot
.88095 .54981 Mdot
.92857 .54981 Mdot
.97619 .60332 Mdot
.001 w
.02381 .01472 m
.07143 .01472 L
.11905 .06822 L
.16667 .06822 L
.21429 .12173 L
.2619 .12173 L
.30952 .17524 L
.35714 .22875 L
.40476 .22875 L
.45238 .28226 L
.5 .28226 L
.54762 .33577 L
.59524 .33577 L
.64286 .38928 L
.69048 .44279 L
.7381 .44279 L
.78571 .4963 L
.83333 .4963 L
.88095 .54981 L
.92857 .54981 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S5.86.1"],

Cell[TextData[{
  "And here are the combined effects of rounding real numbers to the nearest \
machine number and taking the ",
  Cell[BoxData[
      \(TraditionalForm\`log\)], "InlineFormula",
    CellTags->"S5.86.1"],
  " of the result. This is ",
  StyleBox["not", "TI"],
  " a valid test of the ",
  Cell[BoxData[
      \(TraditionalForm\`log\)], "InlineFormula",
    CellTags->"S5.86.1"],
  " function. "
}], "MathCaption",
  CellTags->{"S5.86.1", "1.18"}],

Cell["\<\
Microscope[Log[x], {x, 7, 10},
  PlotJoined -> Real]\
\>", "Input",
  CellLabel->"In[11]:= ",
  CellTags->"S5.86.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.282262 0.428075 [
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.01131 .28226 -42 -4.5 ]
[.01131 .28226 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.5 .01472 m
.5 .02097 L
s
[(7.)] .5 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
.02381 .28226 m
.03006 .28226 L
s
[(1.94591)] .01131 .28226 1 0 Mshowa
.02381 0 m
.02381 .61803 L
s
.02 w
.02381 .01472 Mdot
.07143 .01472 Mdot
.11905 .06822 Mdot
.16667 .06822 Mdot
.21429 .12173 Mdot
.2619 .12173 Mdot
.30952 .17524 Mdot
.35714 .22875 Mdot
.40476 .22875 Mdot
.45238 .28226 Mdot
.5 .28226 Mdot
.54762 .33577 Mdot
.59524 .33577 Mdot
.64286 .38928 Mdot
.69048 .44279 Mdot
.7381 .44279 Mdot
.78571 .4963 Mdot
.83333 .4963 Mdot
.88095 .54981 Mdot
.92857 .54981 Mdot
.97619 .60332 Mdot
.001 w
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .06822 L
.14286 .06822 L
.14286 .06822 L
.19048 .06822 L
.19048 .12173 L
.2381 .12173 L
.2381 .12173 L
.28571 .12173 L
.28571 .17524 L
.33333 .17524 L
.33333 .22875 L
.38095 .22875 L
.38095 .22875 L
.42857 .22875 L
.42857 .28226 L
.47619 .28226 L
.47619 .28226 L
.52381 .28226 L
.52381 .33577 L
.57143 .33577 L
.57143 .33577 L
.61905 .33577 L
.61905 .38928 L
.66667 .38928 L
.66667 .44279 L
.71429 .44279 L
.71429 .44279 L
.7619 .44279 L
.7619 .4963 L
.80952 .4963 L
.80952 .4963 L
.85714 .4963 L
.85714 .54981 L
.90476 .54981 L
.90476 .54981 L
.95238 .54981 L
.95238 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S5.86.1"],

Cell[TextData[{
  "This shows the error in evaluating the sine function at ",
  Cell[BoxData[
      \(TraditionalForm\`31\)], "InlineFormula",
    CellTags->"S5.86.1"],
  " machine numbers near 16. Note how the size of an ulp changes at 16. Note \
also that rounding has moved some points to coincide so that there appear to \
be fewer than ",
  Cell[BoxData[
      \(TraditionalForm\`31\)], "InlineFormula",
    CellTags->"S5.86.1"],
  " points. The scale on the vertical axis represents ulps. "
}], "MathCaption",
  CellTags->{"S5.86.1", "1.19"}],

Cell["\<\
MicroscopicError[Sin[x], {x, 16, 15},
 PlotJoined -> False]\
\>", "Input",
  CellLabel->"In[12]:= ",
  CellTags->"S5.86.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.484639 0.030722 0.316343 0.608843 [
[.48464 .30384 -9 -9 ]
[.48464 .30384 9 0 ]
[.01131 .07281 -24 -4.5 ]
[.01131 .07281 0 4.5 ]
[.01131 .19457 -24 -4.5 ]
[.01131 .19457 0 4.5 ]
[.01131 .43811 -18 -4.5 ]
[.01131 .43811 0 4.5 ]
[.01131 .55988 -18 -4.5 ]
[.01131 .55988 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.48464 .31634 m
.48464 .32259 L
s
[(16.)] .48464 .30384 0 1 Mshowa
0 .31634 m
1 .31634 L
s
.02381 .07281 m
.03006 .07281 L
s
[(-0.4)] .01131 .07281 1 0 Mshowa
.02381 .19457 m
.03006 .19457 L
s
[(-0.2)] .01131 .19457 1 0 Mshowa
.02381 .43811 m
.03006 .43811 L
s
[(0.2)] .01131 .43811 1 0 Mshowa
.02381 .55988 m
.03006 .55988 L
s
[(0.4)] .01131 .55988 1 0 Mshowa
.125 Mabswid
.02381 .10325 m
.02756 .10325 L
s
.02381 .13369 m
.02756 .13369 L
s
.02381 .16413 m
.02756 .16413 L
s
.02381 .22502 m
.02756 .22502 L
s
.02381 .25546 m
.02756 .25546 L
s
.02381 .2859 m
.02756 .2859 L
s
.02381 .34679 m
.02756 .34679 L
s
.02381 .37723 m
.02756 .37723 L
s
.02381 .40767 m
.02756 .40767 L
s
.02381 .46855 m
.02756 .46855 L
s
.02381 .499 m
.02756 .499 L
s
.02381 .52944 m
.02756 .52944 L
s
.02381 .04236 m
.02756 .04236 L
s
.02381 .01192 m
.02756 .01192 L
s
.02381 .59032 m
.02756 .59032 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.01333 w
.02381 .44687 Mdot
.05453 .23079 Mdot
.08525 .01472 Mdot
.11598 .40748 Mdot
.1467 .19141 Mdot
.17742 .58417 Mdot
.20814 .3681 Mdot
.23886 .15202 Mdot
.26959 .54479 Mdot
.30031 .32871 Mdot
.33103 .11263 Mdot
.36175 .5054 Mdot
.39247 .28932 Mdot
.4232 .07325 Mdot
.45392 .46601 Mdot
.48464 .24994 Mdot
.48464 .24994 Mdot
.54608 .42663 Mdot
.60753 .60332 Mdot
.60753 .60332 Mdot
.60753 .60332 Mdot
.66897 .17117 Mdot
.73041 .34786 Mdot
.73041 .34786 Mdot
.73041 .34786 Mdot
.79186 .52455 Mdot
.8533 .09239 Mdot
.8533 .09239 Mdot
.8533 .09239 Mdot
.91475 .26908 Mdot
.97619 .44577 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S5.86.1"],

Cell["\<\
Here is the error in evaluating sine at 21 machine numbers near 31 \
with the points joined by straight lines. \
\>", "MathCaption",
  CellTags->{"S5.86.1", "1.20"}],

Cell["\<\
MicroscopicError[Sin[x], {x, 31, 10},
 PlotJoined -> True]\
\>", "Input",
  CellLabel->"In[13]:= ",
  CellTags->"S5.86.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.296119 0.629955 [
[.5 .28362 -9 -9 ]
[.5 .28362 9 0 ]
[.01131 .04414 -24 -4.5 ]
[.01131 .04414 0 4.5 ]
[.01131 .17013 -24 -4.5 ]
[.01131 .17013 0 4.5 ]
[.01131 .42211 -18 -4.5 ]
[.01131 .42211 0 4.5 ]
[.01131 .5481 -18 -4.5 ]
[.01131 .5481 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.5 .29612 m
.5 .30237 L
s
[(31.)] .5 .28362 0 1 Mshowa
0 .29612 m
1 .29612 L
s
.02381 .04414 m
.03006 .04414 L
s
[(-0.4)] .01131 .04414 1 0 Mshowa
.02381 .17013 m
.03006 .17013 L
s
[(-0.2)] .01131 .17013 1 0 Mshowa
.02381 .42211 m
.03006 .42211 L
s
[(0.2)] .01131 .42211 1 0 Mshowa
.02381 .5481 m
.03006 .5481 L
s
[(0.4)] .01131 .5481 1 0 Mshowa
.125 Mabswid
.02381 .07564 m
.02756 .07564 L
s
.02381 .10713 m
.02756 .10713 L
s
.02381 .13863 m
.02756 .13863 L
s
.02381 .20163 m
.02756 .20163 L
s
.02381 .23312 m
.02756 .23312 L
s
.02381 .26462 m
.02756 .26462 L
s
.02381 .32762 m
.02756 .32762 L
s
.02381 .35911 m
.02756 .35911 L
s
.02381 .39061 m
.02756 .39061 L
s
.02381 .45361 m
.02756 .45361 L
s
.02381 .48511 m
.02756 .48511 L
s
.02381 .5166 m
.02756 .5166 L
s
.02381 .01264 m
.02756 .01264 L
s
.02381 .5796 m
.02756 .5796 L
s
.02381 .6111 m
.02756 .6111 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.02 w
.02381 .41192 Mdot
.07143 .06953 Mdot
.11905 .3571 Mdot
.16667 .01472 Mdot
.21429 .30228 Mdot
.2619 .58985 Mdot
.30952 .24746 Mdot
.35714 .53503 Mdot
.40476 .19264 Mdot
.45238 .48021 Mdot
.5 .13782 Mdot
.54762 .42539 Mdot
.59524 .083 Mdot
.64286 .37057 Mdot
.69048 .02818 Mdot
.7381 .31575 Mdot
.78571 .60332 Mdot
.83333 .26093 Mdot
.88095 .5485 Mdot
.92857 .20611 Mdot
.97619 .49368 Mdot
.001 w
.02381 .41192 m
.07143 .06953 L
.11905 .3571 L
.16667 .01472 L
.21429 .30228 L
.2619 .58985 L
.30952 .24746 L
.35714 .53503 L
.40476 .19264 L
.45238 .48021 L
.5 .13782 L
.54762 .42539 L
.59524 .083 L
.64286 .37057 L
.69048 .02818 L
.7381 .31575 L
.78571 .60332 L
.83333 .26093 L
.88095 .5485 L
.92857 .20611 L
.97619 .49368 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S5.86.1"],

Cell[TextData[{
  "And here are the combined effects of rounding real numbers to the nearest \
machine number and taking the sine of the result. This is ",
  StyleBox["not", "TI"],
  " a valid test of the sine function. The error in evaluating the sine \
function at a machine number near 31 is much smaller than the combination of \
errors resulting from first rounding a real number to the nearest machine \
number and then taking the sine of that machine number. "
}], "MathCaption",
  CellTags->{"S5.86.1", "1.21"}],

Cell["\<\
MicroscopicError[Sin[x], {x, 31, 10},
 PlotJoined -> Real]\
\>", "Input",
  CellLabel->"In[14]:= ",
  CellTags->"S5.86.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.308814 0.00989618 [
[.5 .29631 -9 -9 ]
[.5 .29631 9 0 ]
[.01131 .01193 -18 -4.5 ]
[.01131 .01193 0 4.5 ]
[.01131 .11089 -18 -4.5 ]
[.01131 .11089 0 4.5 ]
[.01131 .20985 -18 -4.5 ]
[.01131 .20985 0 4.5 ]
[.01131 .40778 -12 -4.5 ]
[.01131 .40778 0 4.5 ]
[.01131 .50674 -12 -4.5 ]
[.01131 .50674 0 4.5 ]
[.01131 .6057 -12 -4.5 ]
[.01131 .6057 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.5 .30881 m
.5 .31506 L
s
[(31.)] .5 .29631 0 1 Mshowa
0 .30881 m
1 .30881 L
s
.02381 .01193 m
.03006 .01193 L
s
[(-30)] .01131 .01193 1 0 Mshowa
.02381 .11089 m
.03006 .11089 L
s
[(-20)] .01131 .11089 1 0 Mshowa
.02381 .20985 m
.03006 .20985 L
s
[(-10)] .01131 .20985 1 0 Mshowa
.02381 .40778 m
.03006 .40778 L
s
[(10)] .01131 .40778 1 0 Mshowa
.02381 .50674 m
.03006 .50674 L
s
[(20)] .01131 .50674 1 0 Mshowa
.02381 .6057 m
.03006 .6057 L
s
[(30)] .01131 .6057 1 0 Mshowa
.125 Mabswid
.02381 .03172 m
.02756 .03172 L
s
.02381 .05151 m
.02756 .05151 L
s
.02381 .07131 m
.02756 .07131 L
s
.02381 .0911 m
.02756 .0911 L
s
.02381 .13068 m
.02756 .13068 L
s
.02381 .15048 m
.02756 .15048 L
s
.02381 .17027 m
.02756 .17027 L
s
.02381 .19006 m
.02756 .19006 L
s
.02381 .22964 m
.02756 .22964 L
s
.02381 .24944 m
.02756 .24944 L
s
.02381 .26923 m
.02756 .26923 L
s
.02381 .28902 m
.02756 .28902 L
s
.02381 .32861 m
.02756 .32861 L
s
.02381 .3484 m
.02756 .3484 L
s
.02381 .36819 m
.02756 .36819 L
s
.02381 .38798 m
.02756 .38798 L
s
.02381 .42757 m
.02756 .42757 L
s
.02381 .44736 m
.02756 .44736 L
s
.02381 .46715 m
.02756 .46715 L
s
.02381 .48695 m
.02756 .48695 L
s
.02381 .52653 m
.02756 .52653 L
s
.02381 .54632 m
.02756 .54632 L
s
.02381 .56612 m
.02756 .56612 L
s
.02381 .58591 m
.02756 .58591 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.02 w
.02381 .31063 Mdot
.07143 .30525 Mdot
.11905 .30977 Mdot
.16667 .30439 Mdot
.21429 .30891 Mdot
.2619 .31343 Mdot
.30952 .30805 Mdot
.35714 .31257 Mdot
.40476 .30719 Mdot
.45238 .31171 Mdot
.5 .30633 Mdot
.54762 .31085 Mdot
.59524 .30547 Mdot
.64286 .30998 Mdot
.69048 .30461 Mdot
.7381 .30912 Mdot
.78571 .31364 Mdot
.83333 .30826 Mdot
.88095 .31278 Mdot
.92857 .3074 Mdot
.97619 .31192 Mdot
.001 w
.04762 .02095 m
.04762 .59493 L
.09524 .01558 L
.09524 .59945 L
.14286 .02009 L
.14286 .59407 L
.19048 .01472 L
.19048 .59859 L
.2381 .01923 L
.2381 .60311 L
.28571 .02375 L
.28571 .59773 L
.33333 .01837 L
.33333 .60225 L
.38095 .02289 L
.38095 .59687 L
.42857 .01751 L
.42857 .60138 L
.47619 .02203 L
.47619 .59601 L
.52381 .01665 L
.52381 .60052 L
.57143 .02117 L
.57143 .59515 L
.61905 .01579 L
.61905 .59966 L
.66667 .02031 L
.66667 .59428 L
.71429 .01493 L
.71429 .5988 L
.7619 .01944 L
.7619 .60332 L
.80952 .02396 L
.80952 .59794 L
.85714 .01858 L
.85714 .60246 L
.90476 .0231 L
.90476 .59708 L
.95238 .01772 L
.95238 .6016 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S5.86.1"],

Cell[TextData[{
  "Here we see how bad the square root function really is. It appears that \
near ",
  Cell[BoxData[
      \(TraditionalForm\`3.3\)], "InlineFormula",
    CellTags->"S5.86.1"],
  " its error is bounded by about ",
  Cell[BoxData[
      \(TraditionalForm\`1.5\)], "InlineFormula",
    CellTags->"S5.86.1"],
  " ulps. "
}], "MathCaption",
  CellTags->{"S5.86.1", "1.22"}],

Cell["MicroscopicError[Sqrt[x], {x, 3.3, 100}]", "Input",
  CellLabel->"In[15]:= ",
  CellTags->"S5.86.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0047619 0.291143 0.278546 [
[.5 .27864 -9 -9 ]
[.5 .27864 9 0 ]
[.01131 .0126 -12 -4.5 ]
[.01131 .0126 0 4.5 ]
[.01131 .15187 -24 -4.5 ]
[.01131 .15187 0 4.5 ]
[.01131 .43042 -18 -4.5 ]
[.01131 .43042 0 4.5 ]
[.01131 .56969 -6 -4.5 ]
[.01131 .56969 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.5 .29114 m
.5 .29739 L
s
[(3.3)] .5 .27864 0 1 Mshowa
0 .29114 m
1 .29114 L
s
.02381 .0126 m
.03006 .0126 L
s
[(-1)] .01131 .0126 1 0 Mshowa
.02381 .15187 m
.03006 .15187 L
s
[(-0.5)] .01131 .15187 1 0 Mshowa
.02381 .43042 m
.03006 .43042 L
s
[(0.5)] .01131 .43042 1 0 Mshowa
.02381 .56969 m
.03006 .56969 L
s
[(1)] .01131 .56969 1 0 Mshowa
.125 Mabswid
.02381 .04045 m
.02756 .04045 L
s
.02381 .06831 m
.02756 .06831 L
s
.02381 .09616 m
.02756 .09616 L
s
.02381 .12402 m
.02756 .12402 L
s
.02381 .17972 m
.02756 .17972 L
s
.02381 .20758 m
.02756 .20758 L
s
.02381 .23543 m
.02756 .23543 L
s
.02381 .26329 m
.02756 .26329 L
s
.02381 .319 m
.02756 .319 L
s
.02381 .34685 m
.02756 .34685 L
s
.02381 .37471 m
.02756 .37471 L
s
.02381 .40256 m
.02756 .40256 L
s
.02381 .45827 m
.02756 .45827 L
s
.02381 .48613 m
.02756 .48613 L
s
.02381 .51398 m
.02756 .51398 L
s
.02381 .54183 m
.02756 .54183 L
s
.02381 .59754 m
.02756 .59754 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.002 w
.02381 .57788 Mdot
.02857 .42455 Mdot
.03333 .27121 Mdot
.0381 .39642 Mdot
.04286 .24309 Mdot
.04762 .08975 Mdot
.05238 .49351 Mdot
.05714 .34018 Mdot
.0619 .18684 Mdot
.06667 .5906 Mdot
.07143 .43726 Mdot
.07619 .28393 Mdot
.08095 .40914 Mdot
.08571 .25581 Mdot
.09048 .10247 Mdot
.09524 .50623 Mdot
.1 .3529 Mdot
.10476 .19956 Mdot
.10952 .60332 Mdot
.11429 .44998 Mdot
.11905 .29665 Mdot
.12381 .42186 Mdot
.12857 .26853 Mdot
.13333 .11519 Mdot
.1381 .51895 Mdot
.14286 .36561 Mdot
.14762 .21228 Mdot
.15238 .33749 Mdot
.15714 .18416 Mdot
.1619 .03082 Mdot
.16667 .43458 Mdot
.17143 .28125 Mdot
.17619 .12791 Mdot
.18095 .53167 Mdot
.18571 .37833 Mdot
.19048 .225 Mdot
.19524 .35021 Mdot
.2 .19688 Mdot
.20476 .04354 Mdot
.20952 .4473 Mdot
.21429 .29396 Mdot
.21905 .14063 Mdot
.22381 .54439 Mdot
.22857 .39105 Mdot
.23333 .23772 Mdot
.2381 .36293 Mdot
.24286 .2096 Mdot
.24762 .05626 Mdot
.25238 .46002 Mdot
.25714 .30668 Mdot
.2619 .15335 Mdot
.26667 .55711 Mdot
.27143 .40377 Mdot
.27619 .25044 Mdot
.28095 .37565 Mdot
.28571 .22231 Mdot
.29048 .06898 Mdot
.29524 .47274 Mdot
.3 .3194 Mdot
.30476 .16607 Mdot
.30952 .56983 Mdot
.31429 .41649 Mdot
.31905 .26316 Mdot
.32381 .38837 Mdot
.32857 .23503 Mdot
.33333 .0817 Mdot
.3381 .48546 Mdot
.34286 .33212 Mdot
.34762 .17879 Mdot
.35238 .58255 Mdot
.35714 .42921 Mdot
.3619 .27588 Mdot
.36667 .40109 Mdot
.37143 .24775 Mdot
.37619 .09442 Mdot
.38095 .49818 Mdot
.38571 .34484 Mdot
.39048 .19151 Mdot
.39524 .59527 Mdot
.4 .44193 Mdot
.40476 .2886 Mdot
.40952 .41381 Mdot
.41429 .26047 Mdot
.41905 .10714 Mdot
.42381 .5109 Mdot
.42857 .35756 Mdot
.43333 .20423 Mdot
.4381 .32944 Mdot
.44286 .1761 Mdot
.44762 .02277 Mdot
.45238 .42653 Mdot
.45714 .27319 Mdot
.4619 .11986 Mdot
.46667 .52362 Mdot
.47143 .37028 Mdot
.47619 .21695 Mdot
.48095 .34216 Mdot
.48571 .18882 Mdot
.49048 .03549 Mdot
.49524 .43925 Mdot
.5 .28591 Mdot
.50476 .13258 Mdot
.50952 .53633 Mdot
.51429 .383 Mdot
.51905 .22967 Mdot
.52381 .35488 Mdot
.52857 .20154 Mdot
.53333 .04821 Mdot
.5381 .45197 Mdot
.54286 .29863 Mdot
.54762 .1453 Mdot
.55238 .54905 Mdot
.55714 .39572 Mdot
.5619 .24238 Mdot
.56667 .3676 Mdot
.57143 .21426 Mdot
.57619 .06093 Mdot
.58095 .46468 Mdot
.58571 .31135 Mdot
.59048 .15802 Mdot
.59524 .56177 Mdot
.6 .40844 Mdot
.60476 .2551 Mdot
.60952 .38032 Mdot
.61429 .22698 Mdot
.61905 .07365 Mdot
.62381 .4774 Mdot
.62857 .32407 Mdot
.63333 .17073 Mdot
.6381 .57449 Mdot
.64286 .42116 Mdot
.64762 .26782 Mdot
.65238 .39303 Mdot
.65714 .2397 Mdot
.6619 .08637 Mdot
.66667 .49012 Mdot
.67143 .33679 Mdot
.67619 .18345 Mdot
.68095 .58721 Mdot
.68571 .43388 Mdot
.69048 .28054 Mdot
.69524 .40575 Mdot
.7 .25242 Mdot
.70476 .09908 Mdot
.70952 .50284 Mdot
.71429 .34951 Mdot
.71905 .19617 Mdot
.72381 .32138 Mdot
.72857 .16805 Mdot
.73333 .01472 Mdot
.7381 .41847 Mdot
.74286 .26514 Mdot
.74762 .1118 Mdot
.75238 .51556 Mdot
.75714 .36223 Mdot
.7619 .20889 Mdot
.76667 .3341 Mdot
.77143 .18077 Mdot
.77619 .02743 Mdot
.78095 .43119 Mdot
.78571 .27786 Mdot
.79048 .12452 Mdot
.79524 .52828 Mdot
.8 .37495 Mdot
.80476 .22161 Mdot
.80952 .34682 Mdot
.81429 .19349 Mdot
.81905 .04015 Mdot
.82381 .44391 Mdot
.82857 .29058 Mdot
.83333 .13724 Mdot
.8381 .541 Mdot
.84286 .38767 Mdot
.84762 .23433 Mdot
.85238 .35954 Mdot
.85714 .20621 Mdot
.8619 .05287 Mdot
.86667 .45663 Mdot
.87143 .3033 Mdot
.87619 .14996 Mdot
.88095 .55372 Mdot
.88571 .40038 Mdot
.89048 .24705 Mdot
.89524 .37226 Mdot
.9 .21893 Mdot
.90476 .06559 Mdot
.90952 .46935 Mdot
.91429 .31602 Mdot
.91905 .16268 Mdot
.92381 .56644 Mdot
.92857 .4131 Mdot
.93333 .25977 Mdot
.9381 .38498 Mdot
.94286 .23165 Mdot
.94762 .07831 Mdot
.95238 .48207 Mdot
.95714 .32873 Mdot
.9619 .1754 Mdot
.96667 .57916 Mdot
.97143 .42582 Mdot
.97619 .27249 Mdot
.001 w
.02381 .57788 m
.02857 .42455 L
.03333 .27121 L
.0381 .39642 L
.04286 .24309 L
.04762 .08975 L
.05238 .49351 L
.05714 .34018 L
.0619 .18684 L
.06667 .5906 L
.07143 .43726 L
.07619 .28393 L
.08095 .40914 L
.08571 .25581 L
.09048 .10247 L
.09524 .50623 L
.1 .3529 L
.10476 .19956 L
.10952 .60332 L
.11429 .44998 L
.11905 .29665 L
.12381 .42186 L
.12857 .26853 L
.13333 .11519 L
.1381 .51895 L
.14286 .36561 L
.14762 .21228 L
.15238 .33749 L
.15714 .18416 L
.1619 .03082 L
.16667 .43458 L
.17143 .28125 L
.17619 .12791 L
.18095 .53167 L
.18571 .37833 L
.19048 .225 L
.19524 .35021 L
.2 .19688 L
.20476 .04354 L
.20952 .4473 L
.21429 .29396 L
.21905 .14063 L
.22381 .54439 L
.22857 .39105 L
.23333 .23772 L
.2381 .36293 L
.24286 .2096 L
.24762 .05626 L
.25238 .46002 L
.25714 .30668 L
Mistroke
.2619 .15335 L
.26667 .55711 L
.27143 .40377 L
.27619 .25044 L
.28095 .37565 L
.28571 .22231 L
.29048 .06898 L
.29524 .47274 L
.3 .3194 L
.30476 .16607 L
.30952 .56983 L
.31429 .41649 L
.31905 .26316 L
.32381 .38837 L
.32857 .23503 L
.33333 .0817 L
.3381 .48546 L
.34286 .33212 L
.34762 .17879 L
.35238 .58255 L
.35714 .42921 L
.3619 .27588 L
.36667 .40109 L
.37143 .24775 L
.37619 .09442 L
.38095 .49818 L
.38571 .34484 L
.39048 .19151 L
.39524 .59527 L
.4 .44193 L
.40476 .2886 L
.40952 .41381 L
.41429 .26047 L
.41905 .10714 L
.42381 .5109 L
.42857 .35756 L
.43333 .20423 L
.4381 .32944 L
.44286 .1761 L
.44762 .02277 L
.45238 .42653 L
.45714 .27319 L
.4619 .11986 L
.46667 .52362 L
.47143 .37028 L
.47619 .21695 L
.48095 .34216 L
.48571 .18882 L
.49048 .03549 L
.49524 .43925 L
Mistroke
.5 .28591 L
.50476 .13258 L
.50952 .53633 L
.51429 .383 L
.51905 .22967 L
.52381 .35488 L
.52857 .20154 L
.53333 .04821 L
.5381 .45197 L
.54286 .29863 L
.54762 .1453 L
.55238 .54905 L
.55714 .39572 L
.5619 .24238 L
.56667 .3676 L
.57143 .21426 L
.57619 .06093 L
.58095 .46468 L
.58571 .31135 L
.59048 .15802 L
.59524 .56177 L
.6 .40844 L
.60476 .2551 L
.60952 .38032 L
.61429 .22698 L
.61905 .07365 L
.62381 .4774 L
.62857 .32407 L
.63333 .17073 L
.6381 .57449 L
.64286 .42116 L
.64762 .26782 L
.65238 .39303 L
.65714 .2397 L
.6619 .08637 L
.66667 .49012 L
.67143 .33679 L
.67619 .18345 L
.68095 .58721 L
.68571 .43388 L
.69048 .28054 L
.69524 .40575 L
.7 .25242 L
.70476 .09908 L
.70952 .50284 L
.71429 .34951 L
.71905 .19617 L
.72381 .32138 L
.72857 .16805 L
.73333 .01472 L
Mistroke
.7381 .41847 L
.74286 .26514 L
.74762 .1118 L
.75238 .51556 L
.75714 .36223 L
.7619 .20889 L
.76667 .3341 L
.77143 .18077 L
.77619 .02743 L
.78095 .43119 L
.78571 .27786 L
.79048 .12452 L
.79524 .52828 L
.8 .37495 L
.80476 .22161 L
.80952 .34682 L
.81429 .19349 L
.81905 .04015 L
.82381 .44391 L
.82857 .29058 L
.83333 .13724 L
.8381 .541 L
.84286 .38767 L
.84762 .23433 L
.85238 .35954 L
.85714 .20621 L
.8619 .05287 L
.86667 .45663 L
.87143 .3033 L
.87619 .14996 L
.88095 .55372 L
.88571 .40038 L
.89048 .24705 L
.89524 .37226 L
.9 .21893 L
.90476 .06559 L
.90952 .46935 L
.91429 .31602 L
.91905 .16268 L
.92381 .56644 L
.92857 .4131 L
.93333 .25977 L
.9381 .38498 L
.94286 .23165 L
.94762 .07831 L
.95238 .48207 L
.95714 .32873 L
.9619 .1754 L
.96667 .57916 L
.97143 .42582 L
Mistroke
.97619 .27249 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S5.86.1"],

Cell[TextData[{
  "You cannot examine this function exactly at 1 since it is singular there. \
You can, however, examine it near 1. The label for ",
  StyleBox["1", "MR"],
  " ",
  StyleBox["+", "MR"],
  " ",
  StyleBox["300", "MR"],
  " ",
  StyleBox["Ulp[1]", "MR"],
  " is printed as \"",
  StyleBox["1.", "MR"],
  "\" because the label is limited to 6 characters. "
}], "MathCaption",
  CellTags->{"S5.86.1", "1.23"}],

Cell["\<\
MicroscopicError[1/(x - 1) - 1/(x + 1),
               {x, 1 + 300 Ulp[1]}]\
\>", "Input",
  CellLabel->"In[16]:= ",
  CellTags->"S5.86.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.015873 0.20787 0.398691 [
[.5 .19537 -6 -9 ]
[.5 .19537 6 0 ]
[.01131 .04839 -24 -4.5 ]
[.01131 .04839 0 4.5 ]
[.01131 .12813 -24 -4.5 ]
[.01131 .12813 0 4.5 ]
[.01131 .28761 -18 -4.5 ]
[.01131 .28761 0 4.5 ]
[.01131 .36735 -18 -4.5 ]
[.01131 .36735 0 4.5 ]
[.01131 .44708 -18 -4.5 ]
[.01131 .44708 0 4.5 ]
[.01131 .52682 -18 -4.5 ]
[.01131 .52682 0 4.5 ]
[.01131 .60656 -6 -4.5 ]
[.01131 .60656 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.5 .20787 m
.5 .21412 L
s
[(1.)] .5 .19537 0 1 Mshowa
0 .20787 m
1 .20787 L
s
.02381 .04839 m
.03006 .04839 L
s
[(-0.4)] .01131 .04839 1 0 Mshowa
.02381 .12813 m
.03006 .12813 L
s
[(-0.2)] .01131 .12813 1 0 Mshowa
.02381 .28761 m
.03006 .28761 L
s
[(0.2)] .01131 .28761 1 0 Mshowa
.02381 .36735 m
.03006 .36735 L
s
[(0.4)] .01131 .36735 1 0 Mshowa
.02381 .44708 m
.03006 .44708 L
s
[(0.6)] .01131 .44708 1 0 Mshowa
.02381 .52682 m
.03006 .52682 L
s
[(0.8)] .01131 .52682 1 0 Mshowa
.02381 .60656 m
.03006 .60656 L
s
[(1)] .01131 .60656 1 0 Mshowa
.125 Mabswid
.02381 .06833 m
.02756 .06833 L
s
.02381 .08826 m
.02756 .08826 L
s
.02381 .1082 m
.02756 .1082 L
s
.02381 .14807 m
.02756 .14807 L
s
.02381 .168 m
.02756 .168 L
s
.02381 .18794 m
.02756 .18794 L
s
.02381 .2278 m
.02756 .2278 L
s
.02381 .24774 m
.02756 .24774 L
s
.02381 .26767 m
.02756 .26767 L
s
.02381 .30754 m
.02756 .30754 L
s
.02381 .32748 m
.02756 .32748 L
s
.02381 .34741 m
.02756 .34741 L
s
.02381 .38728 m
.02756 .38728 L
s
.02381 .40721 m
.02756 .40721 L
s
.02381 .42715 m
.02756 .42715 L
s
.02381 .46702 m
.02756 .46702 L
s
.02381 .48695 m
.02756 .48695 L
s
.02381 .50689 m
.02756 .50689 L
s
.02381 .54676 m
.02756 .54676 L
s
.02381 .56669 m
.02756 .56669 L
s
.02381 .58663 m
.02756 .58663 L
s
.02381 .02846 m
.02756 .02846 L
s
.02381 .00852 m
.02756 .00852 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.00667 w
.02381 .20787 Mdot
.03968 .20787 Mdot
.05556 .20787 Mdot
.07143 .60332 Mdot
.0873 .20787 Mdot
.10317 .20787 Mdot
.11905 .20787 Mdot
.13492 .20787 Mdot
.15079 .20787 Mdot
.16667 .20787 Mdot
.18254 .20787 Mdot
.19841 .20787 Mdot
.21429 .20787 Mdot
.23016 .20787 Mdot
.24603 .20787 Mdot
.2619 .20787 Mdot
.27778 .20787 Mdot
.29365 .20787 Mdot
.30952 .20787 Mdot
.3254 .20787 Mdot
.34127 .20787 Mdot
.35714 .20787 Mdot
.37302 .20787 Mdot
.38889 .20787 Mdot
.40476 .20787 Mdot
.42063 .20787 Mdot
.43651 .20787 Mdot
.45238 .20787 Mdot
.46825 .20787 Mdot
.48413 .20787 Mdot
.5 .40456 Mdot
.51587 .20787 Mdot
.53175 .20787 Mdot
.54762 .20787 Mdot
.56349 .40463 Mdot
.57937 .20787 Mdot
.59524 .20787 Mdot
.61111 .20787 Mdot
.62698 .20787 Mdot
.64286 .20787 Mdot
.65873 .20787 Mdot
.6746 .01472 Mdot
.69048 .20787 Mdot
.70635 .20787 Mdot
.72222 .20787 Mdot
.7381 .20787 Mdot
.75397 .20787 Mdot
.76984 .37499 Mdot
.78571 .05599 Mdot
.80159 .20787 Mdot
.81746 .20787 Mdot
.83333 .05865 Mdot
.84921 .20787 Mdot
.86508 .20787 Mdot
.88095 .20787 Mdot
.89683 .20787 Mdot
.9127 .20787 Mdot
.92857 .20787 Mdot
.94444 .20787 Mdot
.96032 .20787 Mdot
.97619 .20787 Mdot
.001 w
.02381 .20787 m
.03968 .20787 L
.05556 .20787 L
.07143 .60332 L
.0873 .20787 L
.10317 .20787 L
.11905 .20787 L
.13492 .20787 L
.15079 .20787 L
.16667 .20787 L
.18254 .20787 L
.19841 .20787 L
.21429 .20787 L
.23016 .20787 L
.24603 .20787 L
.2619 .20787 L
.27778 .20787 L
.29365 .20787 L
.30952 .20787 L
.3254 .20787 L
.34127 .20787 L
.35714 .20787 L
.37302 .20787 L
.38889 .20787 L
.40476 .20787 L
.42063 .20787 L
.43651 .20787 L
.45238 .20787 L
.46825 .20787 L
.48413 .20787 L
.5 .40456 L
.51587 .20787 L
.53175 .20787 L
.54762 .20787 L
.56349 .40463 L
.57937 .20787 L
.59524 .20787 L
.61111 .20787 L
.62698 .20787 L
.64286 .20787 L
.65873 .20787 L
.6746 .01472 L
.69048 .20787 L
.70635 .20787 L
.72222 .20787 L
.7381 .20787 L
.75397 .20787 L
.76984 .37499 L
.78571 .05599 L
.80159 .20787 L
Mistroke
.81746 .20787 L
.83333 .05865 L
.84921 .20787 L
.86508 .20787 L
.88095 .20787 L
.89683 .20787 L
.9127 .20787 L
.92857 .20787 L
.94444 .20787 L
.96032 .20787 L
.97619 .20787 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S5.86.1"],

Cell[TextData[{
  "One point needs to be made clear here since rounding errors are often \
misunderstood and blame is incorrectly placed on an algorithm that has \
nothing to do with the error. Algorithms are designed to map the set of \
machine numbers into the set of machine numbers. To consider other numbers \
does not make sense. As far as the computer is concerned there ",
  StyleBox["are", "TI"],
  " no other numbers. So, for example, if you want to find the square root of \
",
  Cell[BoxData[
      \(TraditionalForm\`49  \[Pi]/50\)], "InlineFormula",
    CellTags->"S5.86.1"],
  ", you might do it as follows. "
}], "Text",
  CellTags->{"S5.86.1", "1.24"}],

Cell[TextData[{
  "Start with a good numerical approximation to ",
  Cell[BoxData[
      \(TraditionalForm\`49  \[Pi]/50\)], "InlineFormula",
    CellTags->"S5.86.1"],
  ". "
}], "MathCaption",
  CellTags->{"S5.86.1", "1.25"}],

Cell["a = N[49 Pi/50, 30]", "Input",
  CellLabel->"In[17]:= ",
  CellTags->"S5.86.1"],

Cell[BoxData[
    \(3.07876080051799737369339051561391282651323`30\)], "Output",
  CellLabel->"Out[17]= ",
  CellTags->"S5.86.1"],

Cell[TextData[{
  "This finds the nearest machine number to ",
  StyleBox["a", "MR"],
  ". "
}], "MathCaption",
  CellTags->{"S5.86.1", "1.26"}],

Cell["b = N[a]", "Input",
  CellLabel->"In[18]:= ",
  CellTags->"S5.86.1"],

Cell[BoxData[
    \(3.07876080051799716`\)], "Output",
  CellLabel->"Out[18]= ",
  CellTags->"S5.86.1"],

Cell[TextData[{
  "This finds the square root of the machine number ",
  StyleBox["b", "MR"],
  " using the machine\[Hyphen]precision algorithm for square root. "
}], "MathCaption",
  CellTags->{"S5.86.1", "1.27"}],

Cell["c = Sqrt[b]", "Input",
  CellLabel->"In[19]:= ",
  CellTags->"S5.86.1"],

Cell[BoxData[
    \(1.75463979224170003`\)], "Output",
  CellLabel->"Out[19]= ",
  CellTags->"S5.86.1"],

Cell[TextData[{
  "Here the error in ",
  StyleBox["c", "MR"],
  " is measured in ulps. This result gives the error for the particular \
machine on which this example was run. Your machine may give a very different \
result. "
}], "MathCaption",
  CellTags->{"S5.86.1", "1.28"}],

Cell["(SetPrecision[c,30]-Sqrt[a])/$MachineEpsilon", "Input",
  CellLabel->"In[20]:= ",
  CellTags->"S5.86.1"],

Cell[BoxData[
    \(\(-1.22218789820841622`\)\)], "Output",
  CellLabel->"Out[20]= ",
  CellTags->"S5.86.1"],

Cell[TextData[{
  "Here we see that the error is much larger than half an ulp. However, the \
problem is not with the square root function. The square root function should \
not be blamed for the rounding error incurred in converting the number ",
  StyleBox["a", "MR"],
  " to the machine number ",
  StyleBox["b", "MR"],
  ". In fact, the square root function has an error less than 1 ulp. "
}], "Text",
  CellTags->{"S5.86.1", "1.29"}],

Cell[TextData[{
  "Here is the \"correct\" value for the square root of ",
  StyleBox["b", "MR"],
  ". "
}], "MathCaption",
  CellTags->{"S5.86.1", "1.30"}],

Cell["d = Sqrt[SetPrecision[b, 30]]", "Input",
  CellLabel->"In[21]:= ",
  CellTags->"S5.86.1"],

Cell[BoxData[
    \(1.7546397922417002921821754735173101642922`30.301\)], "Output",
  CellLabel->"Out[21]= ",
  CellTags->"S5.86.1"],

Cell[TextData[{
  "This shows that the square root function on this machine ",
  StyleBox["is", "TI"],
  " sloppy; it could do better. But it is not as bad as an incorrect analysis \
would suggest. "
}], "MathCaption",
  CellTags->{"S5.86.1", "1.31"}],

Cell["(SetPrecision[c, 30] - d)/$MachineEpsilon", "Input",
  CellLabel->"In[22]:= ",
  CellTags->"S5.86.1"],

Cell[BoxData[
    \(\(-0.954183817470033446`\)\)], "Output",
  CellLabel->"Out[22]= ",
  CellTags->"S5.86.1"]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 800}, {0, 600}},
WindowSize->{520, 455},
WindowMargins->{{Automatic, 86}, {-14, Automatic}},
Visible->True,
StyleDefinitions -> "HelpBrowser.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "S5.86.1"->{
    Cell[1709, 49, 145, 6, 70, "Subsection",
      CellTags->{"S5.86.1", "1.1"}],
    Cell[1857, 57, 3155, 66, 70, "Text",
      CellTags->{"S5.86.1", "1.2"}],
    Cell[5015, 125, 3574, 70, 70, "Text",
      CellTags->{"S5.86.1", "1.3"}],
    Cell[8592, 197, 112, 2, 70, "Caption",
      CellTags->"S5.86.1"],
    Cell[8707, 201, 1514, 41, 70, "Text",
      CellTags->{"S5.86.1", "1.4"}],
    Cell[10224, 244, 4276, 80, 70, "Text",
      CellTags->{"S5.86.1", "1.5"}],
    Cell[14503, 326, 84, 1, 70, "Caption",
      CellTags->"S5.86.1"],
    Cell[14590, 329, 1000, 19, 70, "Text",
      CellTags->{"S5.86.1", "1.6"}],
    Cell[15593, 350, 1009, 23, 70, "Text",
      CellTags->{"S5.86.1", "1.7"}],
    Cell[16605, 375, 158, 7, 70, "Caption",
      CellTags->"S5.86.1"],
    Cell[16766, 384, 79, 1, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.8"}],
    Cell[16848, 387, 92, 2, 70, "Input",
      CellTags->"S5.86.1"],
    Cell[16943, 391, 88, 1, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.9"}],
    Cell[17034, 394, 71, 2, 70, "Input",
      CellTags->"S5.86.1"],
    Cell[17108, 398, 107, 3, 70, "Output",
      CellTags->"S5.86.1"],
    Cell[17218, 403, 99, 1, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.10"}],
    Cell[17320, 406, 103, 2, 70, "Input",
      CellTags->"S5.86.1"],
    Cell[17426, 410, 170, 4, 70, "Output",
      CellTags->"S5.86.1"],
    Cell[17599, 416, 86, 1, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.11"}],
    Cell[17688, 419, 97, 2, 70, "Input",
      CellTags->"S5.86.1"],
    Cell[17788, 423, 160, 4, 70, "Output",
      CellTags->"S5.86.1"],
    Cell[17951, 429, 284, 7, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.12"}],
    Cell[18238, 438, 101, 2, 70, "Input",
      CellTags->"S5.86.1"],
    Cell[18342, 442, 113, 3, 70, "Output",
      CellTags->"S5.86.1"],
    Cell[18458, 447, 99, 1, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.13"}],
    Cell[18560, 450, 104, 2, 70, "Input",
      CellTags->"S5.86.1"],
    Cell[18667, 454, 114, 3, 70, "Output",
      CellTags->"S5.86.1"],
    Cell[18784, 459, 130, 4, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.14"}],
    Cell[18917, 465, 132, 5, 70, "Input",
      CellTags->"S5.86.1"],
    Cell[19052, 472, 114, 3, 70, "Output",
      CellTags->"S5.86.1"],
    Cell[19169, 477, 630, 13, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.15"}],
    Cell[19802, 492, 127, 5, 70, "Input",
      CellTags->"S5.86.1"],
    Cell[19932, 499, 108, 3, 70, "Output",
      CellTags->"S5.86.1"],
    Cell[20043, 504, 229, 7, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.16"}],
    Cell[20275, 513, 121, 5, 70, "Input",
      CellTags->"S5.86.1"],
    Cell[20399, 520, 2110, 122, 70, 2036, 119, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S5.86.1"],
    Cell[22512, 644, 377, 11, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.17"}],
    Cell[22892, 657, 96, 2, 70, "Input",
      CellTags->"S5.86.1"],
    Cell[22991, 661, 1692, 105, 70, 1618, 102, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S5.86.1"],
    Cell[24686, 768, 461, 14, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.18"}],
    Cell[25150, 784, 126, 5, 70, "Input",
      CellTags->"S5.86.1"],
    Cell[25279, 791, 1996, 124, 70, 1922, 121, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S5.86.1"],
    Cell[27278, 917, 548, 13, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.19"}],
    Cell[27829, 932, 133, 5, 70, "Input",
      CellTags->"S5.86.1"],
    Cell[27965, 939, 2450, 157, 70, 2376, 154, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S5.86.1"],
    Cell[30418, 1098, 175, 4, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.20"}],
    Cell[30596, 1104, 132, 5, 70, "Input",
      CellTags->"S5.86.1"],
    Cell[30731, 1111, 2559, 170, 70, 2485, 167, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S5.86.1"],
    Cell[33293, 1283, 519, 9, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.21"}],
    Cell[33815, 1294, 132, 5, 70, "Input",
      CellTags->"S5.86.1"],
    Cell[33950, 1301, 3406, 228, 70, 3332, 225, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S5.86.1"],
    Cell[37359, 1531, 385, 12, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.22"}],
    Cell[37747, 1545, 106, 2, 70, "Input",
      CellTags->"S5.86.1"],
    Cell[37856, 1549, 8827, 540, 70, 8753, 537, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S5.86.1"],
    Cell[46686, 2091, 421, 14, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.23"}],
    Cell[47110, 2107, 149, 5, 70, "Input",
      CellTags->"S5.86.1"],
    Cell[47262, 2114, 4596, 293, 70, 4522, 290, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S5.86.1"],
    Cell[51861, 2409, 669, 14, 70, "Text",
      CellTags->{"S5.86.1", "1.24"}],
    Cell[52533, 2425, 226, 7, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.25"}],
    Cell[52762, 2434, 85, 2, 70, "Input",
      CellTags->"S5.86.1"],
    Cell[52850, 2438, 129, 3, 70, "Output",
      CellTags->"S5.86.1"],
    Cell[52982, 2443, 144, 5, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.26"}],
    Cell[53129, 2450, 74, 2, 70, "Input",
      CellTags->"S5.86.1"],
    Cell[53206, 2454, 103, 3, 70, "Output",
      CellTags->"S5.86.1"],
    Cell[53312, 2459, 214, 5, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.27"}],
    Cell[53529, 2466, 77, 2, 70, "Input",
      CellTags->"S5.86.1"],
    Cell[53609, 2470, 103, 3, 70, "Output",
      CellTags->"S5.86.1"],
    Cell[53715, 2475, 278, 7, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.28"}],
    Cell[53996, 2484, 110, 2, 70, "Input",
      CellTags->"S5.86.1"],
    Cell[54109, 2488, 108, 3, 70, "Output",
      CellTags->"S5.86.1"],
    Cell[54220, 2493, 438, 9, 70, "Text",
      CellTags->{"S5.86.1", "1.29"}],
    Cell[54661, 2504, 156, 5, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.30"}],
    Cell[54820, 2511, 95, 2, 70, "Input",
      CellTags->"S5.86.1"],
    Cell[54918, 2515, 132, 3, 70, "Output",
      CellTags->"S5.86.1"],
    Cell[55053, 2520, 251, 6, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.31"}],
    Cell[55307, 2528, 107, 2, 70, "Input",
      CellTags->"S5.86.1"],
    Cell[55417, 2532, 109, 3, 70, "Output",
      CellTags->"S5.86.1"]},
  "1.1"->{
    Cell[1709, 49, 145, 6, 70, "Subsection",
      CellTags->{"S5.86.1", "1.1"}]},
  "1.2"->{
    Cell[1857, 57, 3155, 66, 70, "Text",
      CellTags->{"S5.86.1", "1.2"}]},
  "1.3"->{
    Cell[5015, 125, 3574, 70, 70, "Text",
      CellTags->{"S5.86.1", "1.3"}]},
  "1.4"->{
    Cell[8707, 201, 1514, 41, 70, "Text",
      CellTags->{"S5.86.1", "1.4"}]},
  "1.5"->{
    Cell[10224, 244, 4276, 80, 70, "Text",
      CellTags->{"S5.86.1", "1.5"}]},
  "1.6"->{
    Cell[14590, 329, 1000, 19, 70, "Text",
      CellTags->{"S5.86.1", "1.6"}]},
  "1.7"->{
    Cell[15593, 350, 1009, 23, 70, "Text",
      CellTags->{"S5.86.1", "1.7"}]},
  "1.8"->{
    Cell[16766, 384, 79, 1, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.8"}]},
  "1.9"->{
    Cell[16943, 391, 88, 1, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.9"}]},
  "1.10"->{
    Cell[17218, 403, 99, 1, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.10"}]},
  "1.11"->{
    Cell[17599, 416, 86, 1, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.11"}]},
  "1.12"->{
    Cell[17951, 429, 284, 7, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.12"}]},
  "1.13"->{
    Cell[18458, 447, 99, 1, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.13"}]},
  "1.14"->{
    Cell[18784, 459, 130, 4, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.14"}]},
  "1.15"->{
    Cell[19169, 477, 630, 13, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.15"}]},
  "1.16"->{
    Cell[20043, 504, 229, 7, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.16"}]},
  "1.17"->{
    Cell[22512, 644, 377, 11, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.17"}]},
  "1.18"->{
    Cell[24686, 768, 461, 14, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.18"}]},
  "1.19"->{
    Cell[27278, 917, 548, 13, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.19"}]},
  "1.20"->{
    Cell[30418, 1098, 175, 4, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.20"}]},
  "1.21"->{
    Cell[33293, 1283, 519, 9, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.21"}]},
  "1.22"->{
    Cell[37359, 1531, 385, 12, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.22"}]},
  "1.23"->{
    Cell[46686, 2091, 421, 14, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.23"}]},
  "1.24"->{
    Cell[51861, 2409, 669, 14, 70, "Text",
      CellTags->{"S5.86.1", "1.24"}]},
  "1.25"->{
    Cell[52533, 2425, 226, 7, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.25"}]},
  "1.26"->{
    Cell[52982, 2443, 144, 5, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.26"}]},
  "1.27"->{
    Cell[53312, 2459, 214, 5, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.27"}]},
  "1.28"->{
    Cell[53715, 2475, 278, 7, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.28"}]},
  "1.29"->{
    Cell[54220, 2493, 438, 9, 70, "Text",
      CellTags->{"S5.86.1", "1.29"}]},
  "1.30"->{
    Cell[54661, 2504, 156, 5, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.30"}]},
  "1.31"->{
    Cell[55053, 2520, 251, 6, 70, "MathCaption",
      CellTags->{"S5.86.1", "1.31"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"S5.86.1", 56166, 2555},
  {"1.1", 62703, 2726},
  {"1.2", 62797, 2729},
  {"1.3", 62887, 2732},
  {"1.4", 62978, 2735},
  {"1.5", 63069, 2738},
  {"1.6", 63161, 2741},
  {"1.7", 63253, 2744},
  {"1.8", 63345, 2747},
  {"1.9", 63441, 2750},
  {"1.10", 63538, 2753},
  {"1.11", 63636, 2756},
  {"1.12", 63734, 2759},
  {"1.13", 63833, 2762},
  {"1.14", 63931, 2765},
  {"1.15", 64030, 2768},
  {"1.16", 64130, 2771},
  {"1.17", 64229, 2774},
  {"1.18", 64329, 2777},
  {"1.19", 64429, 2780},
  {"1.20", 64529, 2783},
  {"1.21", 64629, 2786},
  {"1.22", 64729, 2789},
  {"1.23", 64830, 2792},
  {"1.24", 64931, 2795},
  {"1.25", 65025, 2798},
  {"1.26", 65125, 2801},
  {"1.27", 65225, 2804},
  {"1.28", 65325, 2807},
  {"1.29", 65425, 2810},
  {"1.30", 65518, 2813},
  {"1.31", 65618, 2816}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 145, 6, 70, "Subsection",
  CellTags->{"S5.86.1", "1.1"}],
Cell[1857, 57, 3155, 66, 70, "Text",
  CellTags->{"S5.86.1", "1.2"}],
Cell[5015, 125, 3574, 70, 70, "Text",
  CellTags->{"S5.86.1", "1.3"}],
Cell[8592, 197, 112, 2, 70, "Caption",
  CellTags->"S5.86.1"],
Cell[8707, 201, 1514, 41, 70, "Text",
  CellTags->{"S5.86.1", "1.4"}],
Cell[10224, 244, 4276, 80, 70, "Text",
  CellTags->{"S5.86.1", "1.5"}],
Cell[14503, 326, 84, 1, 70, "Caption",
  CellTags->"S5.86.1"],
Cell[14590, 329, 1000, 19, 70, "Text",
  CellTags->{"S5.86.1", "1.6"}],
Cell[15593, 350, 1009, 23, 70, "Text",
  CellTags->{"S5.86.1", "1.7"}],
Cell[16605, 375, 158, 7, 70, "Caption",
  CellTags->"S5.86.1"],
Cell[16766, 384, 79, 1, 70, "MathCaption",
  CellTags->{"S5.86.1", "1.8"}],
Cell[16848, 387, 92, 2, 70, "Input",
  CellTags->"S5.86.1"],
Cell[16943, 391, 88, 1, 70, "MathCaption",
  CellTags->{"S5.86.1", "1.9"}],
Cell[17034, 394, 71, 2, 70, "Input",
  CellTags->"S5.86.1"],
Cell[17108, 398, 107, 3, 70, "Output",
  CellTags->"S5.86.1"],
Cell[17218, 403, 99, 1, 70, "MathCaption",
  CellTags->{"S5.86.1", "1.10"}],
Cell[17320, 406, 103, 2, 70, "Input",
  CellTags->"S5.86.1"],
Cell[17426, 410, 170, 4, 70, "Output",
  CellTags->"S5.86.1"],
Cell[17599, 416, 86, 1, 70, "MathCaption",
  CellTags->{"S5.86.1", "1.11"}],
Cell[17688, 419, 97, 2, 70, "Input",
  CellTags->"S5.86.1"],
Cell[17788, 423, 160, 4, 70, "Output",
  CellTags->"S5.86.1"],
Cell[17951, 429, 284, 7, 70, "MathCaption",
  CellTags->{"S5.86.1", "1.12"}],
Cell[18238, 438, 101, 2, 70, "Input",
  CellTags->"S5.86.1"],
Cell[18342, 442, 113, 3, 70, "Output",
  CellTags->"S5.86.1"],
Cell[18458, 447, 99, 1, 70, "MathCaption",
  CellTags->{"S5.86.1", "1.13"}],
Cell[18560, 450, 104, 2, 70, "Input",
  CellTags->"S5.86.1"],
Cell[18667, 454, 114, 3, 70, "Output",
  CellTags->"S5.86.1"],
Cell[18784, 459, 130, 4, 70, "MathCaption",
  CellTags->{"S5.86.1", "1.14"}],
Cell[18917, 465, 132, 5, 70, "Input",
  CellTags->"S5.86.1"],
Cell[19052, 472, 114, 3, 70, "Output",
  CellTags->"S5.86.1"],
Cell[19169, 477, 630, 13, 70, "MathCaption",
  CellTags->{"S5.86.1", "1.15"}],
Cell[19802, 492, 127, 5, 70, "Input",
  CellTags->"S5.86.1"],
Cell[19932, 499, 108, 3, 70, "Output",
  CellTags->"S5.86.1"],
Cell[20043, 504, 229, 7, 70, "MathCaption",
  CellTags->{"S5.86.1", "1.16"}],
Cell[20275, 513, 121, 5, 70, "Input",
  CellTags->"S5.86.1"],
Cell[20399, 520, 2110, 122, 70, 2036, 119, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S5.86.1"],
Cell[22512, 644, 377, 11, 70, "MathCaption",
  CellTags->{"S5.86.1", "1.17"}],
Cell[22892, 657, 96, 2, 70, "Input",
  CellTags->"S5.86.1"],
Cell[22991, 661, 1692, 105, 70, 1618, 102, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S5.86.1"],
Cell[24686, 768, 461, 14, 70, "MathCaption",
  CellTags->{"S5.86.1", "1.18"}],
Cell[25150, 784, 126, 5, 70, "Input",
  CellTags->"S5.86.1"],
Cell[25279, 791, 1996, 124, 70, 1922, 121, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S5.86.1"],
Cell[27278, 917, 548, 13, 70, "MathCaption",
  CellTags->{"S5.86.1", "1.19"}],
Cell[27829, 932, 133, 5, 70, "Input",
  CellTags->"S5.86.1"],
Cell[27965, 939, 2450, 157, 70, 2376, 154, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S5.86.1"],
Cell[30418, 1098, 175, 4, 70, "MathCaption",
  CellTags->{"S5.86.1", "1.20"}],
Cell[30596, 1104, 132, 5, 70, "Input",
  CellTags->"S5.86.1"],
Cell[30731, 1111, 2559, 170, 70, 2485, 167, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S5.86.1"],
Cell[33293, 1283, 519, 9, 70, "MathCaption",
  CellTags->{"S5.86.1", "1.21"}],
Cell[33815, 1294, 132, 5, 70, "Input",
  CellTags->"S5.86.1"],
Cell[33950, 1301, 3406, 228, 70, 3332, 225, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S5.86.1"],
Cell[37359, 1531, 385, 12, 70, "MathCaption",
  CellTags->{"S5.86.1", "1.22"}],
Cell[37747, 1545, 106, 2, 70, "Input",
  CellTags->"S5.86.1"],
Cell[37856, 1549, 8827, 540, 70, 8753, 537, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S5.86.1"],
Cell[46686, 2091, 421, 14, 70, "MathCaption",
  CellTags->{"S5.86.1", "1.23"}],
Cell[47110, 2107, 149, 5, 70, "Input",
  CellTags->"S5.86.1"],
Cell[47262, 2114, 4596, 293, 70, 4522, 290, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S5.86.1"],
Cell[51861, 2409, 669, 14, 70, "Text",
  CellTags->{"S5.86.1", "1.24"}],
Cell[52533, 2425, 226, 7, 70, "MathCaption",
  CellTags->{"S5.86.1", "1.25"}],
Cell[52762, 2434, 85, 2, 70, "Input",
  CellTags->"S5.86.1"],
Cell[52850, 2438, 129, 3, 70, "Output",
  CellTags->"S5.86.1"],
Cell[52982, 2443, 144, 5, 70, "MathCaption",
  CellTags->{"S5.86.1", "1.26"}],
Cell[53129, 2450, 74, 2, 70, "Input",
  CellTags->"S5.86.1"],
Cell[53206, 2454, 103, 3, 70, "Output",
  CellTags->"S5.86.1"],
Cell[53312, 2459, 214, 5, 70, "MathCaption",
  CellTags->{"S5.86.1", "1.27"}],
Cell[53529, 2466, 77, 2, 70, "Input",
  CellTags->"S5.86.1"],
Cell[53609, 2470, 103, 3, 70, "Output",
  CellTags->"S5.86.1"],
Cell[53715, 2475, 278, 7, 70, "MathCaption",
  CellTags->{"S5.86.1", "1.28"}],
Cell[53996, 2484, 110, 2, 70, "Input",
  CellTags->"S5.86.1"],
Cell[54109, 2488, 108, 3, 70, "Output",
  CellTags->"S5.86.1"],
Cell[54220, 2493, 438, 9, 70, "Text",
  CellTags->{"S5.86.1", "1.29"}],
Cell[54661, 2504, 156, 5, 70, "MathCaption",
  CellTags->{"S5.86.1", "1.30"}],
Cell[54820, 2511, 95, 2, 70, "Input",
  CellTags->"S5.86.1"],
Cell[54918, 2515, 132, 3, 70, "Output",
  CellTags->"S5.86.1"],
Cell[55053, 2520, 251, 6, 70, "MathCaption",
  CellTags->{"S5.86.1", "1.31"}],
Cell[55307, 2528, 107, 2, 70, "Input",
  CellTags->"S5.86.1"],
Cell[55417, 2532, 109, 3, 70, "Output",
  CellTags->"S5.86.1"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

